==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QPixmapCache_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpixmapcache.h>
#include <QtCore/QVariant>
#include <QtGui/qpixmap.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPixmapCache(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPixmapCache")
    QPixmapCache *_ptr = reinterpret_cast<QPixmapCache *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QPixmapCache_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QPixmapCache *__qt_this = new(__qtjambi_ptr) QPixmapCache();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPixmapCache
void __qt_destruct_QPixmapCache(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPixmapCache")
    reinterpret_cast<QPixmapCache*>(ptr)->~QPixmapCache();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPixmapCache::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_initialize_1native__Lio_qt_gui_QPixmapCache_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPixmapCache_0, sizeof(QPixmapCache), typeid(QPixmapCache), false, &deleter_QPixmapCache, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::cacheLimit()
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_cacheLimit__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::cacheLimit()")
    jint __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QPixmapCache::cacheLimit();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::clear()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_clear__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::clear()")
    QTJAMBI_TRY {
        QPixmapCache::clear();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::find(QPixmapCache::Key,QPixmap*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_find_1native_1cref_1QPixmapCache_1Key_1QPixmap_1ptr__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::find(QPixmapCache::Key,QPixmap*)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        QPixmap* __qt_pixmap1 = QtJambiAPI::objectFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::find(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::find(QString,QPixmap*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_find_1native_1cref_1QString_1QPixmap_1ptr__Ljava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 jstring key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::find(QString,QPixmap*)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_key0 = qtjambi_cast<QString>(__jni_env, key0);
        QPixmap* __qt_pixmap1 = QtJambiAPI::objectFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::find(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::insert(QPixmap)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_insert_1native_1cref_1QPixmap__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pixmap0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::insert(QPixmap)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmap& __qt_pixmap0 = QtJambiAPI::valueReferenceFromNativeId<QPixmap>(pixmap0);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        QPixmapCache::Key __qt_return_value = QPixmapCache::insert(__qt_pixmap0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::insert(QString,QPixmap)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_insert_1native_1cref_1QString_1cref_1QPixmap__Ljava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 jstring key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::insert(QString,QPixmap)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_key0 = qtjambi_cast<QString>(__jni_env, key0);
        const QPixmap& __qt_pixmap1 = QtJambiAPI::valueReferenceFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::insert(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::remove(QPixmapCache::Key)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_remove_1native_1cref_1QPixmapCache_1Key__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID key0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::remove(QPixmapCache::Key)")
    QTJAMBI_TRY {
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        QPixmapCache::remove(__qt_key0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::remove(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_remove__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring key0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::remove(QString)")
    QTJAMBI_TRY {
        QString  __qt_key0 = qtjambi_cast<QString>(__jni_env, key0);
        QPixmapCache::remove(__qt_key0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::replace(QPixmapCache::Key,QPixmap)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_replace_1native_1cref_1QPixmapCache_1Key_1cref_1QPixmap__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::replace(QPixmapCache::Key,QPixmap)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        const QPixmap& __qt_pixmap1 = QtJambiAPI::valueReferenceFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::replace(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::setCacheLimit(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_setCacheLimit__I)
(JNIEnv *__jni_env,
 jclass,
 jint arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::setCacheLimit(int)")
    QTJAMBI_TRY {
        QPixmapCache::setCacheLimit(static_cast<int>(arg__1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QPixmapCache(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPixmapCache>("QPixmapCache", "io/qt/gui/QPixmapCache");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPixmapCache, {
        ConstructorInfo(&__qt_construct_QPixmapCache_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPixmapCache);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPixmapCache_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpixmapcache.h>
#include <QtCore/QVariant>
#include <QtGui/qpixmap.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPixmapCache(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPixmapCache")
    QPixmapCache *_ptr = reinterpret_cast<QPixmapCache *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPixmapCache()
void __qt_construct_QPixmapCache(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPixmapCache()")
    Q_UNUSED(__java_arguments)
    QPixmapCache *__qt_this = new(__qtjambi_ptr) QPixmapCache();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPixmapCache::QPixmapCache()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_initialize_1native__Lio_qt_gui_QPixmapCache_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::QPixmapCache()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPixmapCache, sizeof(QPixmapCache), typeid(QPixmapCache), false, &deleter_QPixmapCache, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPixmapCache
void __qt_destruct_QPixmapCache(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPixmapCache")
    reinterpret_cast<QPixmapCache*>(ptr)->~QPixmapCache();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPixmapCache::cacheLimit()
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_cacheLimit__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::cacheLimit()")
    jint __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QPixmapCache::cacheLimit();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::clear()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_clear__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::clear()")
    QTJAMBI_TRY {
        QPixmapCache::clear();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::find(QPixmapCache::Key,QPixmap*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_find_1native_1cref_1QPixmapCache_1Key_1QPixmap_1ptr__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::find(QPixmapCache::Key,QPixmap*)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        QPixmap* __qt_pixmap1 = QtJambiAPI::objectFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::find(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::find(QString,QPixmap*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_find_1native_1cref_1QString_1QPixmap_1ptr__Ljava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 jstring key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::find(QString,QPixmap*)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_key0 = qtjambi_cast<QString>(__jni_env, key0);
        QPixmap* __qt_pixmap1 = QtJambiAPI::objectFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::find(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::insert(QPixmap)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_insert_1native_1cref_1QPixmap__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pixmap0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::insert(QPixmap)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmap& __qt_pixmap0 = QtJambiAPI::valueReferenceFromNativeId<QPixmap>(pixmap0);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        QPixmapCache::Key __qt_return_value = QPixmapCache::insert(__qt_pixmap0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::insert(QString,QPixmap)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_insert_1native_1cref_1QString_1cref_1QPixmap__Ljava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 jstring key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::insert(QString,QPixmap)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_key0 = qtjambi_cast<QString>(__jni_env, key0);
        const QPixmap& __qt_pixmap1 = QtJambiAPI::valueReferenceFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::insert(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::remove(QPixmapCache::Key)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_remove_1native_1cref_1QPixmapCache_1Key__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID key0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::remove(QPixmapCache::Key)")
    QTJAMBI_TRY {
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        QPixmapCache::remove(__qt_key0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::remove(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_remove__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring key0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::remove(QString)")
    QTJAMBI_TRY {
        QString  __qt_key0 = qtjambi_cast<QString>(__jni_env, key0);
        QPixmapCache::remove(__qt_key0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::replace(QPixmapCache::Key,QPixmap)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_replace_1native_1cref_1QPixmapCache_1Key_1cref_1QPixmap__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID key0,
 QtJambiNativeID pixmap1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::replace(QPixmapCache::Key,QPixmap)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        const QPixmap& __qt_pixmap1 = QtJambiAPI::valueReferenceFromNativeId<QPixmap>(pixmap1);
        QtJambiAPI::checkThreadOnArgumentQPixmap(__jni_env, "pixmap", typeid(QPixmap));
        __java_return_value = QPixmapCache::replace(__qt_key0, __qt_pixmap1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::setCacheLimit(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_setCacheLimit__I)
(JNIEnv *__jni_env,
 jclass,
 jint arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::setCacheLimit(int)")
    QTJAMBI_TRY {
        QPixmapCache::setCacheLimit(static_cast<int>(arg__1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QPixmapCache(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPixmapCache>("QPixmapCache", "io/qt/gui/QPixmapCache");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPixmapCache, {
        ConstructorInfo(&__qt_construct_QPixmapCache, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPixmapCache);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
